@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Authors;
 # ABSTRACT: a section listing authors
-$Pod::Weaver::Section::Authors::VERSION = '4.011';
+$Pod::Weaver::Section::Authors::VERSION = '4.014';
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
@@ -41,6 +41,9 @@ sub weave_section {
   # can get pluralization for your own custom header. -- rjbs, 2015-03-17
   my $name = $self->header || ($multiple_authors ? 'AUTHORS' : 'AUTHOR');
 
+  $self->log_debug("adding $name section");
+  $self->log_debug("author = $_") for @{ $input->{authors} };
+
   my $authors = [ map {
     Pod::Elemental::Element::Pod5::Ordinary->new({
       content => $_,
@@ -86,7 +89,7 @@ Pod::Weaver::Section::Authors - a section listing authors
 
 =head1 VERSION
 
-version 4.011
+version 4.014
 
 =head1 OVERVIEW
 
@@ -112,7 +115,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
