@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Legal;
 # ABSTRACT: a section for the copyright and license
-$Pod::Weaver::Section::Legal::VERSION = '4.011';
+$Pod::Weaver::Section::Legal::VERSION = '4.014';
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
@@ -49,7 +49,9 @@ has license_file => (
 sub weave_section {
   my ($self, $document, $input) = @_;
 
-  return unless $input->{license};
+  unless ($input->{license}) {
+    $self->log_debug('no license specified, not adding a ' . $self->header . ' section');
+ }
 
   my $notice = $input->{license}->notice;
   chomp $notice;
@@ -59,6 +61,8 @@ sub weave_section {
     $notice .= $self->license_file . "> file included with this distribution.";
   }
 
+  $self->log_debug('adding ' . $self->header . ' section');
+
   push @{ $document->children },
     Pod::Elemental::Element::Nested->new({
       command  => 'head1',
@@ -84,7 +88,7 @@ Pod::Weaver::Section::Legal - a section for the copyright and license
 
 =head1 VERSION
 
-version 4.011
+version 4.014
 
 =head1 OVERVIEW
 
@@ -120,7 +124,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
